@@ -1,7 +1,7 @@
 context("Offline checking and skipping")
 
 test_that("currently_offline interacts with the mock contexts", {
-    expect_false(with_fake_HTTP(currently_offline()))
+    expect_false(with_fake_http(currently_offline()))
     expect_true(without_internet(currently_offline()))
 })
 
@@ -13,7 +13,7 @@ public({
         })
     })
     test_that("skip_if_disconnected when 'connected'", {
-        with_fake_HTTP({
+        with_fake_http({
             skip_if_disconnected("This should not skip")
             expect_failure(expect_true(FALSE))
         })
