@@ -30,6 +30,17 @@ test_that("start/end_vignette with mocking (dir exists)", {
     expect_true(identical(g, httr::GET))
 })
 
+test_that("start/end_vignette calls inst/httptest/vignette-start/end.R", {
+    lib <- install_testpkg("testpkg")
+    library(testpkg, lib.loc=lib)
+    expect_false(getOption("testpkg.start.vignette", FALSE))
+    start_vignette(path)
+    expect_true(getOption("testpkg.start.vignette"))
+
+    end_vignette()
+    expect_false(getOption("testpkg.start.vignette", FALSE))
+})
+
 test_that("change_state validation", {
     with_mock_path("foo", {
         expect_error(change_state(), "foo is not valid for change_state()")
